// $Id: G2LController.m,v 1.2 2005/02/22 08:05:07 jeremy Exp $
//
// Copyright (c) 2005 Jeremy Cooper.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
// 3. All advertising materials mentioning features or use of this software
//    must display the following acknowledgement:
//    This product includes software developed by Jeremy Cooper.
// 4. The name of the author may not be used to endorse or promote products
//    derived from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
// NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 
#import "G2LController.h"
#import "EXSConverter.h"

@implementation G2LController

- (void) doConvert: (NSString *) file;
{
	NSString *outFile, *outFileSuggested;
	NSArray *pathComponents;
	NSAlert *alert;
	EXSConverter *converter;
	NSSavePanel *sp;
	int result;

	converter = [[EXSConverter alloc] init];
	
	//
	// Ask the converter if the file looks ok.
	//
	if ([converter fileIsOk: file] != 0) {
		alert = [[NSAlert alloc] init];
		[alert setMessageText: NSLocalizedString(@"NotAReadableEXSFile", @"Not EXS File")];
		[alert setInformativeText: NSLocalizedString(@"NotAReadableEXSFile_Info", @"More information")];
		[alert runModal];
		return;
	}
	
	//
	// Generate a suggested save name.
	//
	pathComponents = [file componentsSeparatedByString: @"/"];
	outFileSuggested = [pathComponents objectAtIndex: ([pathComponents count] - 1)];
	
	//
	// Prompt the user for the save location.
	//
	for (;;) {
		sp = [NSSavePanel savePanel];
		[sp setMessage: NSLocalizedString(@"SavePrompt", @"Choose place to save file")];
		result = [sp runModalForDirectory: nil file: outFileSuggested];
	
		if (result != NSOKButton) {
			// User canceled.
			return;
		}
		
		if (![[sp filename] isEqualToString: file])
			break;
	
		//
		// User is attempting to convert in place.  That won't work.
		//
		alert = [[NSAlert alloc] init];
		[alert setMessageText: NSLocalizedString(@"CantOverwrite", @"Can't save on top of self")];
		[alert runModal];
	}
			
	
	//
	// Convert the file.
	//
	result = [converter
		convert: file
		forOutputAs: [sp filename]
	];
	
	if (result != 0) {
		alert = [[NSAlert alloc] init];
		[alert setMessageText: NSLocalizedString(@"CouldntSave", @"Couldn't save file")];
		[alert setInformativeText: NSLocalizedString(@"CouldntSave_Info", @"Couldn't save file")];
		[alert runModal];
		return;
	}
	
	return;
}

- (IBAction)convert:(id)sender
{
	NSArray *fileTypes = [NSArray arrayWithObject: @"exs"];
	NSOpenPanel *sp;
	int result;
	
	sp = [NSOpenPanel openPanel];
	[sp setPrompt: NSLocalizedString(@"ConvertPrompt", @"Convert")];
	
	result = [sp
		runModalForDirectory:
			@"/Library/Application Support/GarageBand/Instrument Library/Sampler/Sampler Instruments"
		file: nil
		types: fileTypes
	];
	
	if (result == NSOKButton) {
		[self doConvert: [[sp filenames] objectAtIndex: 0]];
	}
}


@end
