/* $Id: exsutil.c,v 1.2 2005/02/22 08:05:07 jeremy Exp $ */
/*
 * Copyright (c) 2005 Jeremy Cooper.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by Jeremy Cooper.
 * 4. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include <sys/types.h>
#include <Carbon/Carbon.h>
#include "exsutil.h"

int EXS_checkHeaderSync(const char *buf, ssize_t len)
{
	/*
	 * The buffer must be long enough for the header that appears before
	 * the 'SOBJ' marker.
	 */
	if (len < 20)
		return -1;

	/*
	 * Check that the given block has an 'SOBJ' magic number.
	 */
	if ((buf[16] == 'S') && (buf[17] == 'O') && (buf[18] == 'B') && (buf[19] == 'J'))
		return 0;
	else
		return -1;
}

int
EXS_fixHeader(char *buf, ssize_t len)
{
	if (len < 20)
		return -1;
	
	buf[ 3] &= 0x7f;
	buf[ 6] &= 0x7f;
	buf[19] = 'T';
	
	return 0;
}

int
EXS_getSInt32(SInt32 *r, const char *buf, ssize_t len)
{
	unsigned const char *u;
	
	if (len < 4)
		return -1;
	
	/* Cast input pointer to unsigned */
	u = buf;
	
	*r = (u[0] << 24) +
	     (u[1] << 16) +
	     (u[2] <<  8) +
	     (u[3]      );

	return 0;
}
